package com.usky.fire.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.common.security.utils.SecurityUtils;
import com.usky.fire.domain.AlarmSmokeControl;
import com.usky.fire.domain.AlarmVideo;
import com.usky.fire.domain.BaseUserCompany;
import com.usky.fire.mapper.AlarmVideoMapper;
import com.usky.fire.service.AlarmVideoService;
import com.usky.fire.service.BaseUserCompanyService;
import com.usky.fire.service.util.OnlineMethod;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 视频监控隐患告警 服务实现类
 * </p>
 *
 * @author JCB
 * @since 2022-08-18
 */
@Service
public class AlarmVideoServiceImpl extends AbstractCrudService<AlarmVideoMapper, AlarmVideo> implements AlarmVideoService {

    @Autowired
    private BaseUserCompanyService baseUserCompanyService;

    @Override
    public CommonPage<AlarmVideo> alarmVideoList(String companyName, Integer handlingStatus, String startDate, String endDate,
                                                 Integer pageNum, Integer pageSize) {
        IPage<AlarmVideo> page = new Page<>(pageNum, pageSize);
        List<AlarmVideo> list = new ArrayList<>();
        LambdaQueryWrapper<BaseUserCompany> QueryWrapper = Wrappers.lambdaQuery();
        QueryWrapper.select(BaseUserCompany::getCompanyId)
                .eq(BaseUserCompany::getUserId, SecurityUtils.getUserId());
        List<BaseUserCompany> comoanyList = baseUserCompanyService.list(QueryWrapper);
        if (CollectionUtils.isNotEmpty(comoanyList)) {
            List<String> companyIdList = new ArrayList<>();
            for (int i = 0; i < comoanyList.size(); i++) {
                companyIdList.add(comoanyList.get(i).getCompanyId());
            }
            LambdaQueryWrapper<AlarmVideo> queryWrapperOne = Wrappers.lambdaQuery();
            queryWrapperOne.select(AlarmVideo::getId, AlarmVideo::getDeviceCode,
                    AlarmVideo::getDeviceName, AlarmVideo::getAlarmType, AlarmVideo::getAlarmTime,
                    AlarmVideo::getCompanyId, AlarmVideo::getCompanyName, AlarmVideo::getHandlingStatus,
                    AlarmVideo::getHandler, AlarmVideo::getHandlingTime, AlarmVideo::getHandlingContent,
                    AlarmVideo::getFalseAlarm, AlarmVideo::getSitePhoto, AlarmVideo::getPortNum, AlarmVideo::getSystemType)
                    .in(AlarmVideo::getCompanyId, companyIdList)
                    .like(StringUtils.isNotBlank(companyName), AlarmVideo::getCompanyName, companyName)
                    .eq(handlingStatus != null, AlarmVideo::getHandlingStatus, handlingStatus)
                    .between(StringUtils.isNotBlank(startDate) && StringUtils.isNotBlank(endDate), AlarmVideo::getAlarmTime, startDate, endDate);
            queryWrapperOne.orderByDesc(AlarmVideo::getId);
            page = this.page(page, queryWrapperOne);
            list = page.getRecords();
            if (CollectionUtils.isNotEmpty(list)) {
                for (int i = 0; i < list.size(); i++) {
                    list.get(i).setAlarmTypeName(OnlineMethod.alarmName(list.get(i).getAlarmType()));
                    list.get(i).setReportContent(list.get(i).getDeviceName() + ",端口号：" + OnlineMethod.alarmName(list.get(i).getPortNum()));
                }
            }
        }
        return new CommonPage<>(list, page.getTotal(), pageSize, pageNum);
    }


    @Override
    public Integer videoCount(List<String> companyIdList, Integer handlingStatus, String companyName, String startDate, String endDate) {
        LambdaQueryWrapper<AlarmVideo> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.in(AlarmVideo::getCompanyId, companyIdList)
                .between(StringUtils.isNotBlank(startDate) && StringUtils.isNotBlank(endDate), AlarmVideo::getAlarmTime, startDate, endDate)
                .like(StringUtils.isNotBlank(companyName), AlarmVideo::getCompanyName, companyName)
                .eq(handlingStatus != null, AlarmVideo::getHandlingStatus, handlingStatus);
        int total = this.count(queryWrapper);
        return total;
    }


    @Override
    public void updateAlarmVideo(AlarmVideo alarmVideo) {
        if (alarmVideo.getId() == 0) {
            LambdaQueryWrapper<AlarmVideo> queryWrapper = Wrappers.lambdaQuery();
            queryWrapper.eq(AlarmVideo::getAlarmType, alarmVideo.getAlarmType())
                    .eq(AlarmVideo::getDeviceCode, alarmVideo.getDeviceCode());
            List<AlarmVideo> list = this.list(queryWrapper);
            if (CollectionUtils.isNotEmpty(list)) {
                for (int i = 0; i < list.size(); i++) {
                    list.get(i).setHandler(SecurityUtils.getUsername());
                    list.get(i).setHandlingTime(LocalDateTime.now());
                    list.get(i).setHandlingStatus(1);
                    list.get(i).setHandlingContent(alarmVideo.getHandlingContent());
                    list.get(i).setHandlerPhone(SecurityUtils.getLoginUser().getSysPerson().getLinkPhone());
                    list.get(i).setFalseAlarm(alarmVideo.getFalseAlarm());
                    this.updateById(list.get(i));
                }
            }
        } else {
            alarmVideo.setHandler(SecurityUtils.getUsername());
            alarmVideo.setHandlingTime(LocalDateTime.now());
            alarmVideo.setHandlingStatus(1);
            alarmVideo.setHandlerPhone(SecurityUtils.getLoginUser().getSysPerson().getLinkPhone());
            this.updateById(alarmVideo);
        }
    }

    @Override
    public List<AlarmVideo> alarmVideoListOne(String companyName, Integer handlingStatus, String startDate, String endDate) {
        List<AlarmVideo> list = new ArrayList<>();
        LambdaQueryWrapper<BaseUserCompany> QueryWrapper = Wrappers.lambdaQuery();
        QueryWrapper.select(BaseUserCompany::getCompanyId)
                .eq(BaseUserCompany::getUserId, SecurityUtils.getUserId());
        List<BaseUserCompany> comoanyList = baseUserCompanyService.list(QueryWrapper);
        if (CollectionUtils.isNotEmpty(comoanyList)) {
            List<String> companyIdList = new ArrayList<>();
            for (int i = 0; i < comoanyList.size(); i++) {
                companyIdList.add(comoanyList.get(i).getCompanyId());
            }
            LambdaQueryWrapper<AlarmVideo> queryWrapperOne = Wrappers.lambdaQuery();
            queryWrapperOne.select(AlarmVideo::getId, AlarmVideo::getDeviceCode,
                    AlarmVideo::getDeviceName, AlarmVideo::getAlarmType, AlarmVideo::getAlarmTime,
                    AlarmVideo::getCompanyId, AlarmVideo::getCompanyName, AlarmVideo::getHandlingStatus,
                    AlarmVideo::getHandler, AlarmVideo::getHandlingTime, AlarmVideo::getHandlingContent,
                    AlarmVideo::getFalseAlarm, AlarmVideo::getSitePhoto, AlarmVideo::getPortNum)
                    .in(AlarmVideo::getCompanyId, companyIdList)
                    .like(StringUtils.isNotBlank(companyName), AlarmVideo::getCompanyName, companyName)
                    .eq(handlingStatus != null, AlarmVideo::getHandlingStatus, handlingStatus)
                    .between(StringUtils.isNotBlank(startDate) && StringUtils.isNotBlank(endDate), AlarmVideo::getAlarmTime, startDate, endDate);
            queryWrapperOne.orderByDesc(AlarmVideo::getId);
            list = this.list(queryWrapperOne);
            if (CollectionUtils.isNotEmpty(list)) {
                for (int i = 0; i < list.size(); i++) {
                    list.get(i).setAlarmTypeName(OnlineMethod.alarmName(list.get(i).getAlarmType()));
                    list.get(i).setReportContent(list.get(i).getDeviceName() + ",端口号：" + OnlineMethod.alarmName(list.get(i).getPortNum()));
                }
            }
        }
        return list;
    }
}
