package com.usky.fire.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.core.util.StringUtils;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.fire.domain.MhPostInspect;
import com.usky.fire.mapper.MhPostInspectMapper;
import com.usky.fire.service.MhPostInspectService;
import com.usky.fire.service.util.OnlineMethod;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.ZoneOffset;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
 * <p>
 * 查岗信息 服务实现类
 * </p>
 *
 * @author JCB
 * @since 2022-08-24
 */
@Service
public class MhPostInspectServiceImpl extends AbstractCrudService<MhPostInspectMapper, MhPostInspect> implements MhPostInspectService {

    @Override
    public CommonPage<MhPostInspect> postInspectRecordList(String companyId, Integer pageNum, Integer pageSize) {
        IPage<MhPostInspect> page = new Page<>(pageNum, pageSize);
        LambdaQueryWrapper<MhPostInspect> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.select(MhPostInspect::getId, MhPostInspect::getInspectStatus, MhPostInspect::getInspectTime,
                MhPostInspect::getSpentTime, MhPostInspect::getReplyTime)
                .eq(MhPostInspect::getCompanyId, companyId);
        page = this.page(page, queryWrapper);
        if (page.getTotal() > 0) {
            for (int i = 0; i < page.getRecords().size(); i++) {
                if (page.getRecords().get(i).getInspectStatus() == 1) {
                    page.getRecords().get(i).setInspectStatusName("已响应");
                    String spentDate = page.getRecords().get(i).getSpentTime() / 60 + ":" + page.getRecords().get(i).getSpentTime() % 60;
                    page.getRecords().get(i).setSpentDate(spentDate);
                } else {
                    //查岗时间与当前时间差
                    long data1 = LocalDateTime.now().toEpochSecond(ZoneOffset.of("+8"));
                    long data2 = page.getRecords().get(i).getInspectTime().toEpochSecond(ZoneOffset.of("+8"));
                    long time = data1 - data2;
                    if (time < 600) {
                        page.getRecords().get(i).setInspectStatusName("等待响应");
                        page.getRecords().get(i).setCountdown(600-time);
                    } else {
                        page.getRecords().get(i).setInspectStatusName("离岗");
                        page.getRecords().get(i).setSpentDate("超时未响应");
                    }
                }
            }
        }
        return new CommonPage<>(page.getRecords(), page.getTotal(), pageSize, pageNum);
    }

    @Override
    public Map<String, Object> postInspectRecordStatistics(String companyId) {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String spentTime = "--:--";
        Integer answeredCount = 0;
        Integer notAnsweredCount = 0;
        Integer count = 0;
        Date date = new Date();
        String startTime = OnlineMethod.getDateTime(date, 7);
        String endTime = format.format(date);
        if (StringUtils.isNotBlank(companyId)) {
            Integer spentTimeAvg = baseMapper.mhPostInspectStatistics(" AVG(spent_time) ", 1, startTime, endTime, null, companyId);
            answeredCount = baseMapper.mhPostInspectStatistics(" count(*) ", 1, startTime, endTime, null, companyId);
            notAnsweredCount = baseMapper.mhPostInspectStatistics(" count(*) ", 0, startTime, endTime, null, companyId);
            count = answeredCount + notAnsweredCount;
            spentTime = spentTimeAvg / 60 + ":" + spentTimeAvg % 60;
        }
        Map<String, Object> map = new HashMap<>();
        map.put("spentTimeAvg", spentTime);
        map.put("count", count);
        map.put("answeredCount", answeredCount);
        map.put("notAnsweredCount", notAnsweredCount);
        return map;
    }

}
